#delimit;
clear;
set more off;
set matsize 500;

/*CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE*/;
global REPDIR = "C:\Users\ecascardi\Dropbox\ELISA\TED\RESEARCH\Data Replication\Poverty and Witch Killing\Poverty&WitchKilling-Data Replication";
cd "$REPDIR";
use events_data;

log using tz_witch-LOG, replace text;

/* Create groups of global variables */;
********************************************************;
global rain = "flood drought";
global controls = "y_vill educat cashcrop kaya hh_sukuma norelig wmgrp";
global controls_y = "educat cashcrop kaya hh_sukuma norelig wmgrp";
global diseases = "any_disease";
global rain_lags = "post_rain any_rain rain_2yr";
********************************************************;

/* TABLE 1: Descriptive Statistics */;

/* Panel A: Crimes per village-year */;
summ witch_murders witch_murders_kaya witch_tot witch_tot_kaya oth_murders oth_murders_kaya tot_murders tot_murders_kaya;

/* Panel B: Natural calamities per village-year */;
summ any_rain rain_2yr drought flood famine any_disease any_livestock;

/* Panel C: Village characteristics */;
summ y_vill educat hh_sukuma cashcrop kaya norelig wmgrp;

clear;

/* TABLE 2: Characteristics of Victims */;
use witch_data;

/* Panel A: Demographic characteristics */;
tab gender_rv;
tab age_rv;
summ age_rv, det;
tab relativ_rv;
tab alone_rv;
tab tribe_rv;

/* Panel B: Socio-economic characteristics */;
tab wealth_rv;
tab livestock_rv;
tab land_rv;

/* Panel C: Timing of witch murders */;
tab year_rv;
tab season_rv;
tab season_rv if month_rv~=.;
tab month_rv;

/* Test whether proportion of witch murders is same in pre-harvest/harvest hungry  season and post-harvest season */;
gen hunger = 0;
replace hunger = . if month_rv==.;
replace hunger =1 if (month_rv>1 & month_rv<8);
ttest hunger=0.5;

clear; 


/* TABLE 3: Impact of Rainfall on Income, Famine */;
use events_data;

/* Create groups of global variables */;
********************************************************;
global rain = "flood drought";
global controls = "y_vill educat cashcrop kaya hh_sukuma norelig wmgrp";
global controls_y = "educat cashcrop kaya hh_sukuma norelig wmgrp";
global diseases = "any_disease";
global rain_lags = "post_rain any_rain rain_2yr";
********************************************************;

/*OLS 1, 2 and 3*/;
gen ward_yr = 100*year + wardno;
tab ward_yr, gen(Iward_yr);
drop Iward_yr1;
foreach num in 2001 {;
	regress y_vill any_rain $controls_y Idiv2 Idiv3 if year==`num' [aw=kaya], robust;
	regress y_vill any_rain $controls_y Idiv2 Idiv3 $diseases if year==`num' [aw=kaya], robust;
	regress y_vill $rain $controls_y Idiv2 Idiv3 if year==`num' [aw=kaya], robust;
	}	;

/*OLS 4*/;
foreach var in famine {;
	areg `var' any_rain $diseases [aw=kaya], a(vid2) robust cluster(vid2);
	};

/*OLS 5*/;
foreach var in any_disease {;
	areg `var' any_rain [aw=kaya], a(vid2) robust cluster(vid2);
	};

clear;


/* TABLE 4: Extreme Rainfall and Witch Murders*/;
use events_data;

/* Groups of global variables */;
********************************************************;
global rain = "flood drought";
global controls = "y_vill educat cashcrop kaya hh_sukuma norelig wmgrp";
global controls_y = "educat cashcrop kaya hh_sukuma norelig wmgrp";
global diseases = "any_disease";
global rain_lags = "post_rain any_rain rain_2yr";
********************************************************;

gen ward_yr = 100*year + wardno;
tab ward_yr, gen(Iward_yr);
drop Iward_yr1;

foreach var in witch_murders {;
	areg `var' any_rain [aw=kaya], a(vid2) robust cluster (vid2);
	regress `var' any_rain $controls Idiv2 Idiv3 [aw=kaya], robust cluster(vid2);
	areg `var' $rain_lags [aw=kaya], a(vid2) robust cluster(vid2);
	areg `var' any_rain $diseases [aw=kaya], a(vid2) robust cluster(vid2);
	areg `var' any_rain Iyear* [aw=kaya], a(vid2) robust cluster(vid2);
	};
	
clear;


/* TABLE 5: Extreme Rainfall and Violent Crime*/;
use events_data;

/* Create groups of global variables */;
********************************************************;
global rain = "flood drought";
global controls = "y_vill educat cashcrop kaya hh_sukuma norelig wmgrp";
global controls_y = "educat cashcrop kaya hh_sukuma norelig wmgrp";
global diseases = "any_disease";
global rain_lags = "post_rain any_rain rain_2yr";
********************************************************;

areg witch_murders any_rain [aw=kaya], a(vid2) robust cluster (vid2);	
areg witch_murders_kaya any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg witch_tot any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg witch_tot_kaya any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg oth_murders any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg oth_murders_kaya any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg tot_murders any_rain [aw=kaya], a(vid2) robust cluster (vid2);
areg tot_murders_kaya any_rain [aw=kaya], a(vid2) robust cluster (vid2);

/* Table A1: Extreme Rainfall and Witch Murders, Robustness*/;
regress witch_murders any_rain $controls Idiv2 Idiv3 [aw=kaya], robust cluster(vid2);
dprobit any_witch_murder any_rain $controls Idiv2 Idiv3, robust cluster(vid2);
oprobit witch_murders any_rain $controls Idiv2 Idiv3 [aw=kaya], robust cluster(vid2);
poisson witch_murders any_rain $controls Idiv2 Idiv3, robust cluster(vid2) nolog;
nbreg witch_murders any_rain $controls Idiv2 Idiv3, robust cluster(vid2) nolog;

/* Figure 1 Proportion of Villages with Extreme Rainfall and Average Witch Murders */;

collapse tot_murders* oth_murders* witch_murders* witch_attacks witch_tot any_rain famine $diseases drought flood, by(year);

label var famine "Proportion famine";
label var any_rain "Proportion extreme rainfall";
label var witch_murders "Average witch murders";
graph7 witch_murders any_rain year, c(l) xlabel(1992 1994 1996 1998 2000 2002) ylabel saving(rain_yr, replace);

log c;

clear;
